@@ -16,8 +16,9 @@ master_doc = "index"
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     "sphinx.ext.autodoc",
-    "sphinx.ext.imgmath",
+    "sphinx.ext.mathjax",
     "sphinx.ext.viewcode",
+    "sphinx.ext.autosummary",
 ]
 
 # The theme to use for HTML and HTML Help pages.  See the documentation for
